document.addEventListener('DOMContentLoaded', () => {
  const newsList = document.getElementById('newsList');
  const langToggle = document.getElementById('langToggle');
  let currentLang = 'en';

  // Simulated news data (in production, this would come from an API)
  const fetchNews = async () => {
    // Simulating API call delay
    await new Promise(resolve => setTimeout(resolve, 1000));
    
    return [
      {
        title: "Example News Title",
        summary: "This is an example news summary that would normally come from an API.",
        link: "#",
        titleZh: "示例新闻标题",
        summaryZh: "这是一个示例新闻摘要，通常来自API。"
      }
      // More news items would be here
    ];
  };

  const renderNews = async () => {
    const loadingSpinner = document.querySelector('.loading-spinner');
    loadingSpinner.style.display = 'flex';
    newsList.innerHTML = '';

    try {
      const news = await fetchNews();
      loadingSpinner.style.display = 'none';

      news.forEach(item => {
        const li = document.createElement('li');
        li.className = 'news-item';
        li.innerHTML = `
          <h2 class="news-title">${currentLang === 'en' ? item.title : item.titleZh}</h2>
          <p class="news-summary">${currentLang === 'en' ? item.summary : item.summaryZh}</p>
          <a href="${item.link}" class="news-link" target="_blank" rel="noopener noreferrer">
            ${currentLang === 'en' ? 'Read More' : '阅读更多'}
          </a>
        `;
        newsList.appendChild(li);
      });
    } catch (error) {
      loadingSpinner.style.display = 'none';
      newsList.innerHTML = `<li class="news-item error">Error loading news: ${error.message}</li>`;
    }
  };

  langToggle.addEventListener('click', () => {
    currentLang = currentLang === 'en' ? 'zh' : 'en';
    langToggle.setAttribute('aria-pressed', currentLang === 'zh');
    renderNews();
  });

  // Initial render
  renderNews();

  // Auto-refresh every 5 minutes
  setInterval(renderNews, 300000);
});
